// The contents of this file are subject to the Mozilla Public License Version
// 1.1
//(the "License"); you may not use this file except in compliance with the
//License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
//
//Software distributed under the License is distributed on an "AS IS" basis,
//WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
//for the specific language governing rights and
//limitations under the License.
//
//The Original Code is "The Columba Project"
//
//The Initial Developers of the Original Code are Frederik Dietz and Timo
// Stich.
//Portions created by Frederik Dietz and Timo Stich are Copyright (C) 2003.
//
//All Rights Reserved.
package org.columba.addressbook.folder;

import org.columba.addressbook.config.FolderItem;
import org.columba.addressbook.model.IGroup;
import org.columba.core.xml.XmlElement;

/**
 * Provides static helper methods for creating new folders.
 * 
 * @author fdietz
 *  
 */
public final class FolderFactory {

	public static AddressbookFolder createAddressbookFolder(
			AbstractFolder parent, String name) {
		XmlElement folder = new XmlElement("folder");
		folder.addAttribute("uid", (AddressbookTreeNode.generateNextFolderUid())
				.toString());
		folder.addAttribute("type", "AddressbookFolder");

		XmlElement property = new XmlElement("property");
		folder.addElement(property);

		property.addAttribute("name", name);

		FolderItem item = new FolderItem(folder);

		AddressbookFolder f = new AddressbookFolder(item);

		parent.add(f);

		return f;
	}

	public static IGroupFolder createGroupFolder(AbstractFolder parent,
			IGroup group) {
		XmlElement folder = new XmlElement("folder");
		folder.addAttribute("uid", (AddressbookTreeNode.generateNextFolderUid())
				.toString());
		folder.addAttribute("type", "GroupFolder");

		XmlElement property = new XmlElement("property");
		folder.addElement(property);

		property.addAttribute("name", group.getName());

		property.addElement(group.getRootElement());

		FolderItem item = new FolderItem(folder);

		GroupFolder f = new GroupFolder(item);

		parent.add(f);

		parent.getFolderItem().getRoot().addElement(folder);

		return f;
	}

}