// The contents of this file are subject to the Mozilla Public License Version
// 1.1
//(the "License"); you may not use this file except in compliance with the
//License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
//
//Software distributed under the License is distributed on an "AS IS" basis,
//WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
//for the specific language governing rights and
//limitations under the License.
//
//The Original Code is "The Columba Project"
//
//The Initial Developers of the Original Code are Frederik Dietz and Timo
// Stich.
//Portions created by Frederik Dietz and Timo Stich are Copyright (C) 2003.
//
//All Rights Reserved.
package org.columba.addressbook.gui.action;

import java.awt.event.ActionEvent;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;

import javax.swing.JFileChooser;

import org.columba.addressbook.folder.AddressbookFolder;
import org.columba.addressbook.gui.frame.AddressbookFrameMediator;
import org.columba.addressbook.model.IContact;
import org.columba.addressbook.parser.VCardParser;
import org.columba.core.gui.frame.FrameMediator;

/**
 * @author fdietz
 *  
 */
public class ExportVCardAction extends DefaultTableAction {

	/**
	 * @param frameMediator
	 * @param name
	 */
	public ExportVCardAction(FrameMediator frameMediator) {
		super(frameMediator, "Export to VCard..");
	}

	/**
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent arg0) {
		AddressbookFrameMediator mediator = (AddressbookFrameMediator) frameMediator;

		//		 get selected folder
		AddressbookFolder sourceFolder = (AddressbookFolder) mediator.getTree()
				.getSelectedFolder();

		//		 get selected contact/group card
		Object[] uids = mediator.getTable().getUids();

		// create open file dialog
		JFileChooser fc = new JFileChooser();
		fc.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
		fc.setApproveButtonText("Select");

		int returnVal = fc.showOpenDialog(frameMediator.getView().getFrame());

		//if user pressed OK button
		if (returnVal == JFileChooser.APPROVE_OPTION) {
			File file = fc.getSelectedFile();

			for (int i = 0; i < uids.length; i++) {
				try {
					IContact contact = sourceFolder.get(uids[i]);
					File f = new File(file, "contact"+uids[i].toString() + ".vcf");

					BufferedOutputStream s = new BufferedOutputStream(
							new FileOutputStream(f));

					VCardParser.write(contact, s);

				} catch (FileNotFoundException e) {

					e.printStackTrace();
				} catch (IOException e) {

					e.printStackTrace();
				} catch (Exception e) {

					e.printStackTrace();
				}
			}
		}
	}

}