// The contents of this file are subject to the Mozilla Public License Version
// 1.1
//(the "License"); you may not use this file except in compliance with the
//License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
//
//Software distributed under the License is distributed on an "AS IS" basis,
//WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
//for the specific language governing rights and
//limitations under the License.
//
//The Original Code is "The Columba Project"
//
//The Initial Developers of the Original Code are Frederik Dietz and Timo
// Stich.
//Portions created by Frederik Dietz and Timo Stich are Copyright (C) 2003.
//
//All Rights Reserved.
package org.columba.addressbook.gui.autocomplete;

import java.util.Hashtable;
import java.util.Iterator;
import java.util.Vector;

import org.columba.addressbook.folder.AbstractFolder;
import org.columba.addressbook.gui.tree.AddressbookTreeModel;
import org.columba.addressbook.model.ContactItem;
import org.columba.addressbook.model.GroupItem;
import org.columba.addressbook.model.HeaderItem;
import org.columba.addressbook.model.IHeaderItem;
import org.columba.addressbook.model.IHeaderItemList;
import org.frapuccino.addresscombobox.ItemProvider;

public class AddressCollector implements ItemProvider, IAddressCollector {

	private	Hashtable _adds = new Hashtable();
	private static AddressCollector instance = new AddressCollector();

	private AddressCollector() {
	}
	
	public static AddressCollector getInstance() {
		return instance;
	}

	/**
	 * Add all contacts and group items to hashmap.
	 * 
	 * @param uid			selected folder uid
	 * @param includeGroup	add groups if true. No groups, otherwise.
	 */
	public void addAllContacts(int uid, boolean includeGroup) {
		IHeaderItemList list = null;

		try {
			AbstractFolder folder = (AbstractFolder) AddressbookTreeModel.getInstance()
					.getFolder(uid);
			list = folder.getHeaderItemList();
		} catch (Exception e) {
			
			e.printStackTrace();
		}

		if (list == null)
			return;

		Iterator it = list.iterator();
		while (it.hasNext()) {
			HeaderItem headerItem = (HeaderItem) it.next();

			if (headerItem.isContact()) {
				// contacts item
				ContactItem item = (ContactItem) headerItem;

				addAddress(item.getDisplayName(), item);

				addAddress(item.getAddress(), item);
			} else {
				if (includeGroup) {
					// group item
					GroupItem item = (GroupItem) headerItem;

					addAddress(item.getDisplayName(), item);
				}
			}
		}
	}

	public void addAddress(String add, IHeaderItem item) {
		if (add != null) {
			_adds.put(add, item);
		}
	}

	public Object[] getAddresses() {
		return _adds.keySet().toArray();
	}

	public IHeaderItem getHeaderItem(String add) {
		return (HeaderItem) _adds.get(add);
	}

	public void clear() {
		_adds.clear();
	}

	/**
	 * @see org.frappucino.addresscombobox.ItemProvider#getMatchingItems(java.lang.String)
	 */
	public Object[] getMatchingItems(String s) {
		Object[] items = getAddresses();

		Vector v = new Vector();
		//		 for each JComboBox item
		for (int k = 0; k < items.length; k++) {
			// to lower case
			String item = items[k].toString().toLowerCase();
			// compare if item starts with str
			if (item.startsWith(s.toLowerCase())) {
				v.add(item);
			}
		}
		return v.toArray();
	}
}