// The contents of this file are subject to the Mozilla Public License Version
// 1.1
//(the "License"); you may not use this file except in compliance with the
//License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
//
//Software distributed under the License is distributed on an "AS IS" basis,
//WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
//for the specific language governing rights and
//limitations under the License.
//
//The Original Code is "The Columba Project"
//
//The Initial Developers of the Original Code are Frederik Dietz and Timo
// Stich.
//Portions created by Frederik Dietz and Timo Stich are Copyright (C) 2003.
//
//All Rights Reserved.
package org.columba.core.gui.action;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.ButtonGroup;
import javax.swing.JRadioButtonMenuItem;

import org.columba.core.action.IMenu;
import org.columba.core.gui.frame.Container;
import org.columba.core.gui.frame.FrameMediator;
import org.columba.core.gui.frame.FrameModel;
import org.columba.core.plugin.PluginHandlerNotFoundException;
import org.columba.core.plugin.PluginLoadingFailedException;
import org.columba.core.plugin.PluginManager;
import org.columba.core.pluginhandler.FramePluginHandler;

/**
 * @author fdietz
 *  
 */
public class SwitchPerspectiveSubmenu extends IMenu implements ActionListener {

	private static final String MAIL_PERSPECTIVE = "ThreePaneMail";

	private static final String ADDRESSBOOK_PERSPECTIVE = "Addressbook";

	private static final String CHAT_PERSPECTIVE = "AlturaFrame";

	private JRadioButtonMenuItem mailMenu;

	private JRadioButtonMenuItem addressbookMenu;

	private JRadioButtonMenuItem chatMenu;

	private ButtonGroup group;

	private FramePluginHandler handler;

	/**
	 * @param controller
	 * @param caption
	 */
	public SwitchPerspectiveSubmenu(FrameMediator controller) {
		super(controller, "Show View",controller.getViewItem().get("id"));

		String id = getFrameMediator().getViewItem().get("id");

		// check if this is a management frame instance
		// -> if so create submenu to switch perspectives
		// -> otherwise, don't create submenu
		boolean isManagedFrame = false;

		try {
			handler = (FramePluginHandler) PluginManager.getInstance()
					.getHandler("org.columba.core.frame");
		} catch (PluginHandlerNotFoundException e) {
			e.printStackTrace();
		}
		
		String[] managedFrames = null;
		if (id != null) {
			managedFrames = handler.getManagedFrames();
			for (int i = 0; i < managedFrames.length; i++) {
				if (id.equals(managedFrames[i]))
					isManagedFrame = true;
			}
		}

		if (!isManagedFrame)
			return;

		group = new ButtonGroup();

		for (int i = 0; i < managedFrames.length; i++) {
			JRadioButtonMenuItem menu = createMenu(managedFrames[i],
					managedFrames[i]);
			if (id.equals(managedFrames[i]))
				menu.setSelected(true);

			add(menu);
		}

	}

	/**
	 * @return
	 */
	private JRadioButtonMenuItem createMenu(String name, String actionCommand) {
		JRadioButtonMenuItem menu = new JRadioButtonMenuItem(name);
		group.add(menu);
		menu.setActionCommand(actionCommand);
		menu.addActionListener(this);
		return menu;
	}

	/**
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent arg0) {
		String action = arg0.getActionCommand();

		FrameMediator mediator = getFrameMediator();

		Container container = mediator.getContainer();

		try {
			FrameModel.getInstance().switchView(container, action);
		} catch (PluginLoadingFailedException e) {
			e.printStackTrace();
		}
	}

}