//The contents of this file are subject to the Mozilla Public License Version 1.1
//(the "License"); you may not use this file except in compliance with the 
//License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
//
//Software distributed under the License is distributed on an "AS IS" basis,
//WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License 
//for the specific language governing rights and
//limitations under the License.
//
//The Original Code is "The Columba Project"
//
//The Initial Developers of the Original Code are Frederik Dietz and Timo Stich.
//Portions created by Frederik Dietz and Timo Stich are Copyright (C) 2003. 
//
//All Rights Reserved.
package org.columba.core.gui.selection;

import java.util.Iterator;
import java.util.List;
import java.util.Vector;

import org.columba.core.command.ICommandReference;

/**
 * Handles the selection of a component identified with an id.
 * <p>
 * We need the id for the {@link SelectionManager}which keeps a map of
 * selection handlers.
 * <p>
 * 
 * 
 * @author fdietz, tstich
 */
public abstract class SelectionHandler {
	/**
	 * id of component for later identification
	 */
	protected String id;

	/**
	 * list of selection listeners
	 */
	protected List selectionListener;

	/**
	 * Default constructor
	 * 
	 * @param id
	 *            id of component
	 */
	public SelectionHandler(String id) {
		this.id = id;

		selectionListener = new Vector();
	}

	/**
	 * Get id of component.
	 * 
	 * @return String id of component
	 */
	public String getId() {
		return id;
	}

	/**
	 * Add selection listener.
	 * 
	 * @param l
	 *            selectionlistener
	 */
	public void addSelectionListener(ISelectionListener l) {
		selectionListener.add(l);
	}

	/**
	 * Fire a selection has changed event.
	 * <p>
	 * Notify all listeners for a change.
	 * 
	 * @param e
	 *            change event
	 */
	protected void fireSelectionChanged(SelectionChangedEvent e) {
		for (Iterator it = selectionListener.iterator(); it.hasNext();) {
			((ISelectionListener) it.next()).selectionChanged(e);
		}
	}

	/**
	 * Get current selection.
	 * 
	 * @return current selection
	 */
	public abstract ICommandReference getSelection();

	/**
	 * Set new selection.
	 * 
	 * @param selection
	 *            new selection
	 */
	public abstract void setSelection(ICommandReference selection);

	/**
	 * @param command
	 */
	public void removeSelectionListener(ISelectionListener l) {
		selectionListener.remove(l);
	}
}