// The contents of this file are subject to the Mozilla Public License Version
// 1.1
//(the "License"); you may not use this file except in compliance with the
//License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
//
//Software distributed under the License is distributed on an "AS IS" basis,
//WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
//for the specific language governing rights and
//limitations under the License.
//
//The Original Code is "The Columba Project"
//
//The Initial Developers of the Original Code are Frederik Dietz and Timo
// Stich.
//Portions created by Frederik Dietz and Timo Stich are Copyright (C) 2003.
//
//All Rights Reserved.
package org.columba.mail.gui.message.viewer;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.Image;
import java.awt.Toolkit;
import java.io.InputStream;

import javax.swing.ImageIcon;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.UIManager;

import org.columba.core.io.StreamUtils;
import org.columba.mail.folder.IMailbox;
import org.columba.mail.gui.frame.MailFrameMediator;
import org.columba.mail.gui.message.MessageController;
import org.columba.ristretto.coder.Base64DecoderInputStream;
import org.columba.ristretto.coder.QuotedPrintableDecoderInputStream;
import org.columba.ristretto.message.MimeHeader;
import org.columba.ristretto.message.MimePart;

/**
 * @author fdietz
 *  
 */
public class ImageViewer extends JPanel implements IMimePartViewer {

	private MessageController mediator;

	private byte[] data;

	private ImageIcon image;

	private int width;

	/**
	 *  
	 */
	public ImageViewer(MessageController mediator) {
		super();

		this.mediator = mediator;

		setLayout(new BorderLayout());

		setBackground(UIManager.getColor("TextArea.background"));

	}

	/**
	 * @see org.columba.mail.gui.message.viewer.IMimePartViewer#view(org.columba.mail.folder.IMailbox,
	 *      java.lang.Object, java.lang.Integer[],
	 *      org.columba.mail.gui.frame.MailFrameMediator)
	 */
	public void view(IMailbox folder, Object uid, Integer[] address,
			MailFrameMediator mediator) throws Exception {

		MimePart bodyPart = folder.getMimePartTree(uid).getFromAddress(address);

		InputStream bodyStream = folder.getMimePartBodyStream(uid, address);

		int encoding = MimeHeader.PLAIN;

		if (bodyPart != null) {
			encoding = bodyPart.getHeader().getContentTransferEncoding();
		}

		switch (encoding) {
		case MimeHeader.QUOTED_PRINTABLE: {
			bodyStream = new QuotedPrintableDecoderInputStream(bodyStream);

			break;
		}

		case MimeHeader.BASE64: {
			bodyStream = new Base64DecoderInputStream(bodyStream);

			break;
		}
		}

		data = StreamUtils.readInByteArray(bodyStream);
	}

	/**
	 * @see org.columba.mail.gui.message.viewer.IViewer#updateGUI()
	 */
	public void updateGUI() throws Exception {

		removeAll();

		image = new ImageIcon(Toolkit.getDefaultToolkit().createImage(data));
		//image = new ImageIcon(data);

		Container parent = mediator.getViewport();
		int cwidth = (int) parent.getWidth();

		// if image is bigger than message viewer size
		if (cwidth < image.getIconWidth()) {
			// scale image
			float scaling = (float) cwidth / image.getIconWidth();

			image = new ImageIcon(image.getImage()
					.getScaledInstance((int) (image.getIconWidth() * scaling),
							(int) (image.getIconHeight() * scaling),
							Image.SCALE_SMOOTH));
		}

		JLabel label = new JLabel(image);
		add(label, BorderLayout.CENTER);

		revalidate();

	}

	/**
	 * @see org.columba.mail.gui.message.viewer.IViewer#getView()
	 */
	public JComponent getView() {
		return this;
	}

	/**
	 * @see org.columba.mail.gui.message.viewer.IViewer#isVisible()
	 */
	public boolean isVisible() {
		return true;
	}

}